# Tests:
#   2.7:
#   assert ::= assert_expr jmp_true LOAD_ASSERT RAISE_VARARGS_1
#   call_function ::= expr expr expr CALL_FUNCTION_2

#   2.6
#   assert ::= assert_expr jmp_true LOAD_ASSERT RAISE_VARARGS_1 come_from_pop

assert isinstance(1, int)

# 2.6.9 DocXMLRPCServer.py
# 2.6
# assert2 ::= assert_expr jmp_true LOAD_ASSERT expr RAISE_VARARGS_2 come_from_pop

for method_name in self:
    if method_name in self:
        method = 'a'
    else:
        assert 0, "instance installed"

    methods = 'b'
#
